queryPattern property

  1. @override
String queryPattern
final

The query pattern to use when querying for this column.

The query pattern is generated automatically by the library.

Generally, this is the same as the name of the column.

For joins and JSON references, this will be a fancy query pattern depending on the join type and referenced columns. These fancy query patterns are generated in PgJoin.call.

Implementation

@override
final String queryPattern;