PgModelHere class

An annotation that marks a class as a PgModel for which an extension should be generated.

The extension will contain the getter methods for the model's properties.

The annotated class must have a static PgModelBuilder field.

Constructors

PgModelHere()
An annotation that marks a class as a PgModel for which an extension should be generated.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited