PgModel<TableType> class
A custom return type for a query.
TableType is used to provide type safety. Objects that require a model
will only allow models of the provided TableType. Also, the model will
only allow columns, values and builders of the provided TableType.
Constructors
-
PgModel(Map<
String, dynamic> ? json, PgValuesList<TableType> ? values, {required PgModelBuilder<TableType, PgModel< builder})TableType> > - A custom return type for a query.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ PgValuesList<
TableType> -
The values of the columns.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
value<
ValueType> (PgQueryColumn< TableType, ValueType, dynamic> column) → ValueType - Returns the value of the given column.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited