PgNoneModifier<TableType> class
A modifier that does not modify the query. Used for when no data needs to be retrieved.
The output type of the query will be a void.
- Inheritance
-
- Object
- PgModifier<
TableType, void, void> - PgNoneModifier
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
previousModifier
→ PgModifier<
TableType, void, dynamic> ? -
The modifier that was applied before this one.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asCSV(
) → PgAsCSVModifier< TableType> -
Available on PgModifier<
Retrieves the response as a CSV string.TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
asCSV(
) → PgAsCSVModifier< TableType> -
Available on PgModifier<
Retrieves the response as a CSV string.TableType, PgJsonMap, dynamic> , provided by the PgMapModifierX extension -
asCSV(
) → PgAsCSVModifier< TableType> -
Available on PgModifier<
Retrieves the response as a CSV string.TableType, PgJsonMap?, dynamic> , provided by the PgMaybeMapModifierX extension -
asRaw(
) → PgAsRawModifier< TableType> -
Available on PgModifier<
TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
count(
CountOption option) → PgCountModifier< TableType> -
Available on PgModifier<
Counts the number of records in the response.TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
limit(
int limit) → PgLimitModifier< TableType> -
Available on PgModifier<
Limits the result with the specified count.TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
maybeSingle(
) → PgMaybeSingleModifier< TableType> -
Available on PgModifier<
Retrieves only one row from the result if there is one.TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
none(
) → PgNoneModifier< TableType> -
Available on PgModifier<
A modifier that does not modify the query. Used for when no data needs to be retrieved.TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
order(
PgColumn< TableType, dynamic, dynamic> column, {bool ascending = false, bool nullsFirst = false}) → PgOrderModifier<TableType> -
Available on PgModifier<
Orders the result with the specifiedTableType, PgJsonList, dynamic> , provided by the PgListModifierX extensioncolumn. -
range(
int start, int end) → PgRangeModifier< TableType> -
Available on PgModifier<
Limits the result to rows within the specified range, inclusive.TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
single(
) → PgSingleModifier< TableType> -
Available on PgModifier<
Retrieves only one row from the result. Result must be one row (e.g. using limit), otherwise this will result in an error.TableType, PgJsonList, dynamic> , provided by the PgListModifierX extension -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited