SupaStreamModifier<TableType, CurrentType, PreviousType> class
A modifier that can be applied to a stream.
{@macro typesafe_postgrest.PgModifier}
- Implementers
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
previousModifier
→ SupaStreamModifier<
TableType, PreviousType, dynamic> ? -
The modifier that was applied before this one.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
limitStream(
int count) → SupaLimitStreamModifier< TableType> -
Available on SupaStreamModifier<
Limits the result with the specifiedTableType, PgJsonList, dynamic> , provided by the SupaListStreamModifierX extensioncount. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orderStream(
PgColumn< TableType, dynamic, dynamic> column, {bool ascending = false}) → SupaOrderStreamModifier<TableType> -
Available on SupaStreamModifier<
Orders the result with the specifiedTableType, PgJsonList, dynamic> , provided by the SupaListStreamModifierX extensioncolumn. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited